@@ -36,6 +36,9 @@
 
 #include "icao2wingspan.inc"
 
+#define sqr(x) ((x)*(x))       
+
+
 #ifdef HAVE_MATH_H
 #define _USE_MATH_DEFINES // for MSVC
 #endif
@@ -148,6 +151,7 @@ void ac_compute(struct acs *acs, struct ac *ac, struct ac_counterpart *ctp, stru
     
     now = time(NULL);
     dt = now - ac->when;
+    //dt = 0; // comment out for reachability snapshot
     //dbg("dt=%d\n", (int)dt);
     ac->flyingdutchman = (dt > gacs->dead_minutes * 60);
     qrbqtf2hw(ac->h, ac->w, ac->speed * dt / 3600.0, ac->qtfdir + (90 * M_PI / 180.0), &h, &w);
@@ -356,10 +360,11 @@ void plot_ac(struct subwin *sw, struct ac *ac){
     int px, py, opx, opy/*, bpx, bpy*/;
     double rad,r;
     int vx,vy,vx1,vy1,vx2,vy2;
-    int fcolor, bcolor, undercursor;
+    int fcolor, bcolor;
     struct ac_counterpart *ctp = sw->type == SWT_KST ? &gacs->infoqso : &gacs->tmpqso;
     struct ac_result *res = sw->type == SWT_KST ? &ac->infores : &ac->tmpres;
 
+    if (!ac) return;
     if (!ac->is_computed) return;
 
     //todo outline
@@ -381,12 +386,12 @@ void plot_ac(struct subwin *sw, struct ac *ac){
     vy2 = (int)round(py - 0.4*r * sin(rad - 0.6) + 0.5);
 
 
-    undercursor = 0;
-    if (sw->mx >= z_min3_d(vx, vx1, vx2) && 
-        sw->my >= z_min3_d(vy, vy1, vy2) &&
-        sw->mx <= z_max3_d(vx, vx1, vx2) &&
-        sw->my <= z_max3_d(vy, vy1, vy2)) undercursor = 1;
-    if (undercursor){
+    //gacs->undercursor = 0;
+    //if (sw->mx >= z_min3_d(vx, vx1, vx2) && 
+    //    sw->my >= z_min3_d(vy, vy1, vy2) &&
+    //    sw->mx <= z_max3_d(vx, vx1, vx2) &&
+    //    sw->my <= z_max3_d(vy, vy1, vy2)) gacs->undercursor = 1;
+    if (*ac->id && strcmp(ac->id, sw->minacid) == 0){
         fcolor = z_makecol(21, 193, 106);
         bcolor = z_makecol(15, 150, 70);
     }else if (/*ac->id &&*/ *ac->id && strcmp(ac->id, gacs->sh.tracked) == 0){
@@ -425,7 +430,7 @@ void plot_ac(struct subwin *sw, struct ac *ac){
     vx2 = (int)round(px - 0.4*r * cos(rad - 0.6));
     vy2 = (int)round(py - 0.4*r * sin(rad - 0.6));
 
-    if (undercursor)    
+   /* if (*ac->id && strcmp(ac->id, sw->minacid) == 0)
     {
         opx = px;
         opy = py;
@@ -434,7 +439,7 @@ void plot_ac(struct subwin *sw, struct ac *ac){
 
         if (!sw->ac_plotinfo) plot_info_ac(sw, sw->screen, ac);
         return;
-    }
+    }*/
 
     if (!res->crossing) return;
     
@@ -466,7 +471,7 @@ void plot_info_ac(struct subwin *sw, SDL_Surface *surface, struct ac *ac){
 
     x = sw->info.x + 4;
     //y = sw->info.y + 4 + 18 * FONT_H;
-    y = sw->info.y;
+    y = sw->info.y + 4;
 
     rect.x = sw->info.x;  // same as plot_info_qso
     rect.y = y;
@@ -480,37 +485,38 @@ void plot_info_ac(struct subwin *sw, SDL_Surface *surface, struct ac *ac){
     SDL_FillRect(sw->screen, &rect, z_makecol(0,0,35)) ;
 
     if (ac){
+		int dy = 0;
         sw->ac_plotinfo = 1;
         color=z_makecol(21, 193, 106);
-        zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ICAO24: %s", ac->id); y += FONT_H + 4;
+        zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ICAO24: %s", ac->id); y += FONT_H + dy;
 
         if (cfg->ac_imperial){
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ASL: %5d ft", ac->feets); y += FONT_H + 4;
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Speed: %3d kt"), ac->knots); y += FONT_H + 4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ASL: %5d ft", ac->feets); y += FONT_H + dy;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Speed: %3d kt"), ac->knots); y += FONT_H + dy;
         }else{
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_ASL_5D_M), ac->asl); y += FONT_H + 4;
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_SPEED4D_KMH), ac->speed); y += FONT_H + 4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_ASL_5D_M), ac->asl); y += FONT_H + dy;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_SPEED4D_KMH), ac->speed); y += FONT_H + dy;
         }
 
         if (/*ac->icaotype != NULL &&*/ strlen(ac->icaotype) > 0) {
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Type:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->icaotype); y += FONT_H + 4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Type:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->icaotype); y += FONT_H + dy;
         }
         if (/*ac->callsign != NULL &&*/ strlen(ac->callsign) > 0) {
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Call:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->callsign); y += FONT_H + 4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Call:  %s")/*VTEXT(T_SPEED4D_KMH)*/, ac->callsign); y += FONT_H + dy;
         }
         if (ac->wingspan == 0) {
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: unknown")); y += FONT_H + 4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: unknown")); y += FONT_H + dy;
         }else{
             if (cfg->ac_imperial) {
-                zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: %d ft"), ac->wingspan); y += FONT_H + 4;
+                zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: %d ft"), ac->wingspan); y += FONT_H + dy;
             }else{
-                zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: %d m"), (int)round(ac->wingspan * 0.3048)); y += FONT_H + 4;
+                zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("WingS: %d m"), (int)round(ac->wingspan * 0.3048)); y += FONT_H + dy;
             }
         }
         time_t upd = time(NULL) - ac->when;
-        zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Updated: %d min"), upd / 60); y += FONT_H + 4;
-        //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("%3.1f %3.1f"), ac->w*180.0/M_PI, ac->h * 180.0 / M_PI); y += FONT_H + 4;
-        //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("%3.1f %3.1f"), ac->kx, ac->ky); y += FONT_H + 4;
+        zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("Updated: %d min"), upd / 60); y += FONT_H + dy;
+        //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("%3.1f %3.1f"), ac->w*180.0/M_PI, ac->h * 180.0 / M_PI); y += FONT_H + dy;
+        //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, TRANSLATE("%3.1f %3.1f"), ac->kx, ac->ky); y += FONT_H + dy;
 
 
         res = sw->type == SWT_KST ? &ac->infores : &ac->tmpres;
@@ -518,9 +524,9 @@ void plot_info_ac(struct subwin *sw, SDL_Surface *surface, struct ac *ac){
             diff = res->start - time(NULL);
             gmtime_r(&res->start, &utc);
 
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_AC_START), utc.tm_hour, utc.tm_min, ((long)diff) / 60, ((long)diff) % 60); y+=FONT_H+4;
-            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_AC_DURAT_LD), (long)(res->stop - res->start)); y+=FONT_H+4;
-            //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "Angle: %d", (int)(res->angle * 180.0 / M_PI)); y+=FONT_H+4;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_AC_START), utc.tm_hour, utc.tm_min, ((long)diff) / 60, ((long)diff) % 60); y+=FONT_H+ dy;
+            zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_AC_DURAT_LD), (long)(res->stop - res->start)); y+=FONT_H+ dy;
+            //zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "Angle: %d", (int)(res->angle * 180.0 / M_PI)); y+=FONT_H+dy;
         }
     }
     SDL_SetClipRect(sw->screen, &oldrect);
@@ -549,7 +555,7 @@ void acs_redraw(struct subwin *sw, struct acs *acs){
             }
         }
     }
-    if (!sw->ac_plotinfo) plot_info_ac(sw, sw->screen, NULL);
+   // if (!sw->ac_plotinfo) plot_info_ac(sw, sw->screen, NULL);
     MUTEX_UNLOCK(acs->sh);
 
 }
@@ -1082,4 +1088,52 @@ void ac_track(struct acs *acs, char *id, int rotnr){
     MUTEX_UNLOCK(acs->sh);
 }
 
+#ifdef Z_HAVE_SDL
+// acs->sh must be locked by caller (returned value can be freeed in worker thread)
+struct ac* ac_find_by_id(struct acs* acs, char *id) {
+    struct ac* ac, *ret = NULL;
+    int i;
 
+    if (!gacs) return NULL;
+    if (!id || !*id) return NULL;
+
+    if (acs->sh.acs) {
+        for (i = 0; i < acs->sh.acs->len; i++) {
+            ac = (struct ac*)g_ptr_array_index(acs->sh.acs, i);
+            if (strcmp(ac->id, id) == 0){
+                ret = ac;
+                break;
+            }
+        }
+    }
+    return ret;
+}
+
+void find_nearest_ac(struct acs* acs, int mouse_x, int mouse_y, double* min, char (*minacid)[AC_ID_MAXLEN]) {
+    *min = G_MAXDOUBLE;
+    if (!acs) return;
+
+    struct subwin* sw = gses->ontop;
+    if (sw->type != SWT_MAP) return;
+
+    int px = mouse_x - sw->x * FONT_W;
+    int py = mouse_y - sw->y * FONT_H;
+    int kx, ky;
+    px2km(sw, px, py, &kx, &ky);
+
+    MUTEX_LOCK(acs->sh);
+    if (acs->sh.acs) {
+        int i;
+        for (i = 0; i < acs->sh.acs->len; i++) {
+            struct ac *ac = (struct ac*)g_ptr_array_index(acs->sh.acs, i);
+
+            double d = sqrt((double)(sqr(ac->kx - kx) + sqr(ac->ky - ky)));
+            if (d < *min) {
+                *min = d;
+                strcpy(*minacid, ac->id);
+            }
+        }
+    }
+    MUTEX_UNLOCK(acs->sh);
+}
+#endif
