@@ -153,6 +153,8 @@ struct acs{
 	void (*load_from_thread)(struct acs* acs);
 	GHashTable* unknownids;
 	MUTEX_DEFINE(unknownids);
+
+	//int undercursor; // main thread
 };
 
 struct ac_info{
@@ -190,6 +192,10 @@ void ac_fill_wingspan(struct acs* acs, struct ac* ac);
 
 struct ac *ac_under(struct acs *acs, struct subwin *sw);
 void ac_track(struct acs *acs, char *id, int rotnr);
+struct ac* ac_find_by_id(struct acs* acs, char* id);
+#ifdef Z_HAVE_SDL
+void find_nearest_ac(struct acs* acs, int mouse_x, int mouse_y, double* min, char (*minacid)[AC_ID_MAXLEN]);
+#endif
 
 //openskynetwork
 int acs_osn_init(struct acs* acs);
