@@ -110,7 +110,7 @@ static int write_adif_qsos(struct band *b, struct config_band *confb, FILE *f){
         "SSB",
         "AM",   /* 5 */
         "FM",
-        "RTTY",
+        "MGM",
         "SSTV",
         "ATV"  /* 9 */
     };
@@ -365,7 +365,8 @@ static int adif_add_qso(struct band *band, GHashTable *hash){
     mode=SAFE_ADIF_ITEM("MODE");
     if (!strcasecmp(mode, "SSB")) q->mode=1;
     else if (!strcasecmp(mode, "CW")) q->mode=2;
-    else if (!strcasecmp(mode, "RTTY")) q->mode=7;
+    else if (!strcasecmp(mode, "RTTY")) q->mode=7; // compatibility, Varna 2014
+    else if (!strcasecmp(mode, "MGM")) q->mode=7;
     else if (!strcasecmp(mode, "AM")) q->mode=5;
     else if (!strcasecmp(mode, "FM")) q->mode=6;
     else if (!strcasecmp(mode, "SSTV")) q->mode=8;
