@@ -14,11 +14,12 @@
 #ifndef __BUTTON_H
 #define __BUTTON_H
 
-#ifdef Z_HAVE_SDL
 
 struct button{
 	int w, h;
+#ifdef Z_HAVE_SDL
     SDL_Surface *surface;
+#endif
     void (*fn)(void *);
     void *data;
     int x, y; 
@@ -26,20 +27,23 @@ struct button{
 	char *text;
 };
 
-struct button *init_button(SDL_Surface *screen, int x, int y, void (*fn)(void *), void *data);
+struct button *init_button(
+#ifdef Z_HAVE_SDL
+        SDL_Surface *screen, 
+#endif
+        int x, int y, void (*fn)(void *), void *data);
 void free_button(struct button *b);
 
 void buttons_clear(GPtrArray *buttons);
+#ifdef Z_HAVE_SDL
 void buttons_redraw(GPtrArray *buttons, SDL_Surface *dst);
 int buttons_mouse(GPtrArray *buttons, int mb, int mx, int my);
-
-
-
 void button_bitmap(struct button *b, SDL_Surface *surface);
+void button_draw(struct button *b, SDL_Surface *dst);
+#endif
+
 void button_text(struct button *b, int font_h, int fcolor, int bcolor, char *text);
 void button_free(struct button *b);
-void button_draw(struct button *b, SDL_Surface *dst);
 
 
 #endif
-#endif
