@@ -1074,6 +1074,19 @@ int cq_run_cw(struct cq *cq){
     dbg("\ncw_run_cq '%s' (extcq %d)\n", raw, gses->extcq);
     if (!raw) return -1;
 
+// maybe move down?
+#ifdef HAVE_HAMLIB
+    if (cfg->cwda_type == CWD_HAMLIB) {
+        trigs_send_morse(gtrigs, raw);
+        if (cq->cw_repeat) {
+            gses->last_cq = cq;
+            gses->last_cq_timer_id = zselect_timer_new(zsel, cq->cw_ts * 100, cq_timer_cw2, cq);
+        }
+        redraw_later();
+        g_free(raw);
+        return 0;
+    }
+#endif
     
     if (gses->extcq > 0){
         remains = cq_remains_run();
@@ -1130,8 +1143,6 @@ int cq_run_ssb(struct cq *cq){
 
     dbg("cq_run_ssb\n");
     cq->mode=MOD_SSB_SSB;
-    cwdaemon_ptt(cwda, 1, 0);
-    cwdaemon_ssbway(cwda, 1); /* soundcard */
 
 #ifdef HAVE_HAMLIB
 	if (gssbd->dsp->type == DSPT_HAMLIB){
@@ -1144,6 +1155,9 @@ int cq_run_ssb(struct cq *cq){
 		return ret;
 	}
 #endif
+	// no PTT when DPST_HAMLIB
+	cwdaemon_ptt(cwda, 1, 0);
+	cwdaemon_ssbway(cwda, 1); /* soundcard */
 
 #ifdef Z_ANDROID
     char *filename = convert_esc(cq->ssb_file, NULL, CE_NONE, time(NULL));
