@@ -17,7 +17,8 @@
 
 struct cq;
 
-enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP, CWD_TTYS_SINGLE, CWD_HAMLIB};
+enum cwtype { CWD_NONE, CWD_PARPORT, CWD_TTYS, CWD_DAVAC4, CWD_CWD, CWD_WINKEY, CWD_WINKEY4x, CWD_WINKEYTCP, CWD_TTYS_SINGLE, CWD_HAMLIB, CWD_DAVAC5
+};
 
 struct cwdaemon {
 	int (*init)    (struct cwdaemon *);
@@ -69,12 +70,11 @@ struct cwdaemon {
     struct ftdi_context *ftdi;
     unsigned char ftdi_state;
     MUTEX_DEFINE(ftdi);
-/*    GMutex *ftdi_mutex;
-#ifdef LEAK_DEBUG_LIST
-    char *ftdi_file;
-    int ftdi_line;
-#endif*/
-
+#endif
+#ifdef HAVE_HIDAPI
+    hid_device* hid;
+    unsigned char hid_state;
+    MUTEX_DEFINE(hid);
 #endif
     int tune;
     int sock;
