@@ -17,6 +17,11 @@
 #include "language2.h"
 #include "rc.h"
 
+//// for usb_info
+//#include "cwdaemon.h"
+//#include "rotar.h"
+//#include "sdev.h"
+
 #ifdef Z_HAVE_LIBFTDI
 int davac4_init(struct cwdaemon *cwda){
     cwda->ftdi = NULL;
@@ -228,7 +233,7 @@ void usb_info(GString *gs){
     int ret;
     struct ftdi_context ftdi;
     struct ftdi_device_list *list, *dev;
-    int ids[] = {0x0403, 0x6001, 
+	int ids[] = {0x0403, 0x6001, 
                  0xA600, 0xE110,
                  0xA600, 0xE111,
                  0xA600, 0xE112,
@@ -236,7 +241,7 @@ void usb_info(GString *gs){
                  0xA600, 0xE114,
                  0x04D8, 0xFB56, // FUNcube Dongle
                  0x04D8, 0xFB31, // FUNcube Dongle Pro+
-				 0x0bda, 0x2838,  // RTL-SDR
+				 0x0bda, 0x2838, // RTL-SDR
                  0};
     int idi;
 #ifdef Z_HAVE_FTDI_USB_GET_STRINGS
@@ -253,29 +258,53 @@ void usb_info(GString *gs){
         g_string_append_printf(gs, "error calling ftdi_init, error=%d %s", ret, ftdi_get_error_string(&ftdi));
         return;
     }
-    for (idi = 0; ids[idi] != 0; idi += 2){
-        ret = ftdi_usb_find_all(&ftdi, &list, ids[idi], ids[idi+1]);
+	for (idi = 0; ids[idi] != 0; idi += 2){
+		int vid = ids[idi];
+		int pid = ids[idi + 1];
+
+        ret = ftdi_usb_find_all(&ftdi, &list, vid, pid);
         if (ret < 0) {
             g_string_append_printf(gs, "error calling ftdi_usb_find_all, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
             return;
         }
         if (ret == 0) continue;
         for (dev = list; dev != NULL; dev = dev->next){
-            // FIXME g_string_append_printf(gs, "%04x:%04x  ", dev->dev->descriptor.idVendor, dev->dev->descriptor.idProduct);
+			g_string_append_printf(gs, "%04x:%04x  ", vid, pid);
+
+			/*if (cwda != NULL && cwda->ftdi != NULL && vid == 0xa600 && pid == 0xe110){
+				g_string_append_printf(gs, "Probably opened as Davac4\n");
+				continue;
+			}
+			if (rotars != NULL){
+				int i;
+				MUTEX_LOCK(rotars);
+				for (i = 0; i<rotars->len; i++){
+					struct rotar * rot = (struct rotar *) g_ptr_array_index(rotars, i);
+					if (rot != NULL && rot->type == ROT_OK1ZIA_FTDI && rot->sdev != NULL && rot->sdev->sconn != NULL && rot->sdev->sconn->opened){
+						g_string_append_printf(gs, "Probably opened as Rotar %c", rot->rotchar);
+					}
+				}
+				MUTEX_UNLOCK(rotars);
+			}*/
+
 #ifdef Z_HAVE_FTDI_USB_GET_STRINGS
             ret = ftdi_usb_get_strings(&ftdi, dev->dev, manufacturer, 128, description, 128, serial, 128);
             if (ret < 0){
-                g_string_append_printf(gs, "Can't get strings, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
+                g_string_append_printf(gs, "Can't get strings, error=%d %s", ret, ftdi_get_error_string(&ftdi));
+				//if (ret == -4) g_string_append_printf(gs, "  Maybe not handled by Winusb? Try to use Zadig to set Winusb for this device");
+				g_string_append_printf(gs, "\n");
+				continue;
             }else{
                 g_string_append_printf(gs, "%s %s ", manufacturer, description);
                 if (strlen(serial)>0 && serial[0]!='?')
                     g_string_append_printf(gs, "%s  ", serial);
             }
 #endif
-            if (ids[idi] == 0x04D8){
+            if (vid == 0x04D8){
                 g_string_append_printf(gs, "\n");
                 continue;
             }
+
             ret = ftdi_usb_open_dev(&ftdi, dev->dev);
             if (ret < 0){
                 g_string_append_printf(gs, "Can't open device, error=%d %s\n", ret, ftdi_get_error_string(&ftdi));
