@@ -875,8 +875,19 @@ void menu_qso_check(void *arg){
 
 
 void call_info_map(struct dialog_data *dlg, struct dialog_item_data *di){
-	GString *gs = g_string_new("http://k7fry.com/grid/?qth=");
+	GString *gs = g_string_new("https://qrb.vaiz.cz/?mywwl=");
+
+	if (ctest != NULL)
+		g_string_append(gs, ctest->pwwlo);
+	else
+		g_string_append(gs, cfg->pwwlo);
+
+	g_string_append(gs, "&dstwwl=");
 	g_string_append(gs, di->item->text);
+    if (aband) {
+        g_string_append(gs, "&mhz=");
+        g_string_append_printf(gs, "%d", aband->qrg_min / 1000);
+    }
 	z_browser(gs->str);
 	g_string_free(gs, TRUE);
 }
