@@ -66,7 +66,7 @@ void sw_dxc_connected_handler(void *xxx);
 void sw_dxc_read_handler(void *xxx);
 void sw_dxc_disconnect(struct subwin *sw);
 
-char *sw_dxc_call_under(struct subwin *sw, int x, int y, double *out_qrg);
+char *sw_dxc_call_under(struct subwin *sw, int x, int y, double *out_qrg, char **out_ref);
 void sw_dxc_toggle_highlight(struct subwin *sw, char *call, int val);
 int sw_dxc_line_color(struct subwin *sw, char *line);
 char *sw_dxc_counterp(struct subwin *sw, char *line, int *color); // thread unsafe!
