@@ -9,7 +9,7 @@
 */
 #include "header.h"
 
-
+#include "beacondb.h"
 #include "bfu.h"
 #include "chart.h"
 #include "control.h"
@@ -1323,6 +1323,7 @@ destroy:;
     qrv_recalc_wkd(qrv);
 	progress(VTEXT(T_UPDATING_QRBQTF));
 	qrv_recalc_qrbqtf(qrv);
+	beacondb_recalc_qrbqtf(gbeacondb);
 	progress(VTEXT(T_UPDATING_GAIN));
     qrv_recalc_gst(qrv);
 	progress(VTEXT(T_SEN_OVER_NET));
