@@ -256,6 +256,9 @@ void read_exc_files(struct excdb *excdb, enum exctype exctype, gchar *excname){
         if (strcasecmp(ename, "rcont")==0) {
             ret = load_vexc_from_mem(excdb, txt_tucnakvexcrcont, sizeof(txt_tucnakvexcrcont));
         }
+        if (strcasecmp(ename, "lcont")==0) {
+            ret = load_vexc_from_mem(excdb, txt_tucnakvexclcont, sizeof(txt_tucnakvexclcont));
+        }
         if (strcasecmp(ename, "uba")==0) {
             ret = load_vexc_from_mem(excdb, txt_tucnakvexcuba, sizeof(txt_tucnakvexcuba));
         }
@@ -447,14 +450,14 @@ gchar *find_exc_by_call(struct excdb *excdb, const gchar *call){
     
     switch(excdb->exctype){
         case EXC_WAZ:  
-            dwi = get_dw_item_by_call(dw, call);
+			dwi = get_dw_item_by_call(dw, call);
             if (!dwi) return NULL;
             
             g_snprintf(s, 20, "%02d", dwi->waz);
             return s;
             
         case EXC_ITU:
-            dwi = get_dw_item_by_call(dw, call);
+			dwi = get_dw_item_by_call(dw, call);
             if (!dwi) return NULL;
             g_snprintf(s, 20, "%02d", dwi->itu);
             return s;
