@@ -283,7 +283,7 @@ void html_qsos(GString *gs, struct band *b, struct config_band *confb){
 		"CWr",
 		"AM",
 		"FM",
-		"RTTY",
+		"MGM",
 		"SSTV",
 		"ATV"
 	};
