@@ -395,7 +395,7 @@ show_history:
                     if (ev->x >= ' ' && ev->x < 0x100 && !ev->y) {
                         char c;
                         if (il->readonly) break;
-						dbg("gses->last_cq = %p\n", gses->last_cq);
+						//dbg("gses->last_cq = %p\n", gses->last_cq);
 						if (il->band && gses->last_cq){
 							if ((gses->last_cq->mode == MOD_CW_CW && gses->last_cq->cw_breakable) ||
 								(gses->last_cq->mode != MOD_CW_CW && gses->last_cq->ssb_breakable)){
