@@ -1,6 +1,6 @@
 /*
     kst - ON4KST chat
-    Copyright (C) 2011-2022 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2024 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -344,7 +344,7 @@ void kst_right_mouse_2(struct subwin *sw){
 	add_to_menu(&mi, CTEXT(T_MESSAGE), "", CTEXT(T_HK_MESSAGE), sw_kst_message, NULL, 0); items++;
 	add_to_menu(&mi, CTEXT(T_INFO), "", CTEXT(T_HK_INFO), sw_kst_info, NULL, 0); items++;
 #ifdef Z_HAVE_SDL
-	if (gacs) { add_to_menu(&mi, CTEXT(T_AC_INFO), "", CTEXT(T_HK_AC_INFO), sw_kst_ac_info, NULL, 0); items++; }
+	if (gacs) { add_to_menu(&mi, CTEXT(T_AC_INFO), "", CTEXT(T_HK_AC_INFO), sw_kst_ac_info_call, NULL, 0); items++; }
 #endif
 	if (aband) {
 		add_to_menu(&mi, CTEXT(T_USE), "", CTEXT(T_HK_USE), sw_kst_use, NULL, 0);
@@ -1096,7 +1096,7 @@ void sw_kst_info(void *itdata, void *menudata){
 }
 
 #ifdef Z_HAVE_SDL
-void sw_kst_ac_info(void *itdata /* NULL or WWL*/, void *menudata){
+void sw_kst_ac_info_call(void *itdata /* NULL or WWL*/, void *menudata){
     struct qrv_item *qi;
     char call[40], *c;
     struct subwin *sw = (struct subwin*)menudata;
@@ -1285,7 +1285,7 @@ int kst_read_line(struct subwin *sw, char *line){
         z_str_uc(call);
         z_strip_from(call, ' ');
         z_strip_from(call, ')');
-        z_strip_from(call, '-');
+        //z_strip_from(call, '-');
 		if (call[0] == '(') {
 			zg_free0(c1); zg_free0(c2); zg_free0(c3); zg_free0(c4);	zg_free0(c5);
 			return 1; // skip
@@ -1636,7 +1636,7 @@ GPtrArray* sw_kst_calls_under(struct subwin *sw, int n, int y){
 				//if (*e == '\0') break; // while
 								   
 				*e = '\0';
-				if (regcmp(b, "^([0-9A-Z]{1,3}\\/)?([0-9][A-Z]|[A-Z]{1,2}[0-9]?)[0-9]{1,4}[A-Z]{1,4}(\\/[A-Z0-9]{1,3})*(-[0-9]{1,2})*$") == 0){
+				if (regcmp(b, "^([0-9A-Z]{1,3}\\/)?([0-9][A-Z]|[A-Z]{1,2}[0-9]?)[0-9]{1,4}[A-Z]{1,4}(\\/[A-Z0-9]{1,3})*(-[0-9]{1,5})*$") == 0){
 				//if (z_can_be_call(b, ZCBC_MINUS)){
 
 					int eq = zg_ptr_array_find_str(ret, b);
