@@ -12,6 +12,7 @@
 
 #include "ac.h"
 #include "alsa.h"
+#include "beacondb.h"
 #include "charsets.h"
 #ifdef Z_HAVE_SDL
 #include "cordata.h"
@@ -684,6 +685,7 @@ static void init(void)
     wizz = init_wizz();
 	namedb = init_namedb();
 	masterdb = init_masterdb();
+	gbeacondb = init_beacondb();
     init_sconns();
     init_rotars();
 #ifdef Z_HAVE_SDL    
@@ -702,6 +704,7 @@ static void init(void)
 	read_namedb_files(namedb);
 	/*read_ebw_files(cw,namedb);*/
 	read_masterdb_files(masterdb);
+	read_beacondb_files(gbeacondb);
     
     init_sound();
     gnet = init_net();
@@ -826,6 +829,7 @@ static void terminate_all_subsystems(void)
     free_wizz(wizz);
 	free_namedb(namedb);
 	free_masterdb(masterdb);
+	free_beacondb(gbeacondb);
     free_rotars();
     free_spotdb(spotdb);
 	free_httpd(httpd);
@@ -872,10 +876,10 @@ static void terminate_all_subsystems(void)
 void redraw(void){
     
     //dbg("redraw()  paused=%d\n", sdl->paused);
-    if (sdl->paused) return;
 
 #ifdef Z_HAVE_SDL        
     if (sdl) {
+        if (sdl->paused) return;
         sdl_redraw_screen();
     }
     else
