@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2016  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2024  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -11,6 +11,7 @@
 #include "header.h"
 
 #include "ac.h"
+#include "beacondb.h"
 #include "bfu.h"
 #ifdef Z_HAVE_SDL
 #include "cordata.h"
@@ -20,6 +21,7 @@
 #include "icons.h"
 #include "kbdbind.h"
 #include "kbd.h"
+#include "kst.h"
 #include "main.h"
 #include "map.h"
 #include "qrvdb.h"
@@ -98,7 +100,8 @@ int sw_map_kbd_func(struct subwin* sw, struct event* ev, int fw) {
             sw->gdirty = 1;
             qrv_recalc_wkd(qrv);
             qrv_recalc_qrbqtf(qrv);
-            qrv_recalc_gst(qrv);
+			beacondb_recalc_qrbqtf(gbeacondb);
+			qrv_recalc_gst(qrv);
             map_recalc_gst(sw, aband);
             sw_map_redraw(sw, aband, 0);
             break;
@@ -176,20 +179,21 @@ int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
     if ((ev->b & BM_ACT) == B_DOWN){
         lmx = ev->mx - sw->x * FONT_W;
         lmy = ev->my - sw->y * FONT_H;
+        int f = cfg->usetouch ? 2 : 1;
 
 		if (lmx >= 0 && 
 			lmy > 0 && 
-			lmx < sdl->home->w && 
-			lmy < sdl->home->h)
+			lmx < sdl->home->w * f && 
+			lmy < sdl->home->h * f)
 		{
             map_for_photo(sw, aband, 0);
 			return 1;
 		}
 
-		if (lmx >= sw->map.w - sdl->zoomin->w && 
+		if (lmx >= sw->map.w - sdl->zoomin->w * f &&
 			lmy >= 0 &&
 			lmx < sw->map.w &&
-			lmy < sdl->zoomin->h)
+			lmy < sdl->zoomin->h * f)
 		{
             lmx = sw->x * FONT_W + sw->screen->w/2;
             lmy = sw->y * FONT_H + sw->screen->h/2;
@@ -197,8 +201,8 @@ int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
 			return 1;
 		}
 
-		if (lmx >= sw->map.w - sdl->zoomout->w && 
-			lmy >= sw->map.h - sdl->zoomout->h &&
+		if (lmx >= sw->map.w - sdl->zoomout->w * f &&
+			lmy >= sw->map.h - sdl->zoomout->h * f &&
 			lmx < sw->map.w &&
 			lmy < sw->map.h)
 		{
@@ -209,7 +213,7 @@ int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
 		}
     }
 	if (ev->b & B_MOVE){
-        if (!gacs) plot_nearest_qso(sw, aband);
+        /*if (!gacs || !gacs->undercursor)*/ plot_nearest_qso_beacon_ac(sw, aband);
         //plot_nearest_qrv(sw, aband);
         plot_qrb_qth(sw, sw->screen, sdl->mouse_x, sdl->mouse_y);
         return 1;
@@ -247,32 +251,48 @@ int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
 			/*dbg("right\n");*/
 			if (lmx < 0) break;
 			mi = new_menu(1);
-			mi->rtext = TRANSLATE("Turn antenna");
+			mi->rtext = TRANSLATE("Turn antenna / AS info");
 			MUTEX_LOCK(rotars);
 			int i = 0;
 			for (i = 0; i<rotars->len; i++){
 				struct rotar *rot = (struct rotar *) g_ptr_array_index(rotars, i);
 				add_to_menu(&mi, rot->desc, "", "", MENU_FUNC map_turn_rot, GINT_TO_POINTER(i), 0);
 			}
-			struct ac *ac = ac_under(gacs, sw);
+            int kx, ky;
+            px2km(sw, lmx, lmy, &kx, &ky);
+            double qrb, qtf;
+            km2qrbqtf(kx, ky, &qrb, &qtf);
+
+            struct ac *ac = ac_under(gacs, sw);
 			g_free(sw->acunder);
-			sw->acunder = NULL;
+            sw->acunder = NULL;
+            g_free(sw->wwlunder);
+            sw->wwlunder = NULL;
+            int n = 0;
+            if (gacs) {
+                char wwl[12];
+                double h2, w2;
+                if (qrbqtf2hw(gses->myh, gses->myw, qrb, qtf, &h2, &w2) == 0) {
+                    hw2loc(wwl, h2 * 180 / M_PI, w2 * 180 / M_PI, 10);
+                    sw->wwlunder = g_strdup(wwl);
+                    add_to_menu(&mi, CTEXT(T_AC_INFO), "", CTEXT(T_HK_AC_INFO), MENU_FUNC sw_map_ac_info_wwl, NULL, 0);
+                    n++;
+                }
+            }
 			if (ac){
 				sw->acunder = g_strdup(ac->id);
 				for (i = 0; i<rotars->len; i++){
 					struct rotar *rot = (struct rotar *) g_ptr_array_index(rotars, i);
+
 					add_to_menu(&mi, "Track airplane", rot->rotstr, rot->rotstr, MENU_FUNC map_track, GINT_TO_POINTER(i), 0);
-				}
+                    n++;
+                }
 			}
 
 			MUTEX_UNLOCK(rotars);
-			if (i == 0) break;
+			if (n == 0) break;
 			set_window_ptr(gses->win, ev->x - 3, ev->y + 1);
 
-			int kx, ky;
-			double qrb, qtf;
-			px2km(sw, lmx, lmy, &kx, &ky);
-			km2qrbqtf(kx, ky, &qrb, &qtf);
 			int uhel = (int)round(qtf * 180 / M_PI);
 			sw->uhel = uhel;
 			do_menu(mi, sw);
@@ -346,7 +366,7 @@ void move_map(struct subwin *sw, struct band *band, int dx, int dy){
         sw_map_redraw_rect(sw, &dst, band, 0);
     }
 
-    if (!gacs) plot_nearest_qso(sw, band); 
+    /*if (!gacs || !gacs->undercursor)*/ plot_nearest_qso_beacon_ac(sw, band);
    // plot_nearest_qrv(sw, band); 
 //    dbg("move_map ox=%d oy=%d\n", sw->ox, sw->oy);
 }
@@ -374,6 +394,11 @@ void sw_map_redraw_rect(struct subwin *sw, SDL_Rect *area, struct band *band, in
         plot_qrvs(sw, sw->l1map, band, area);
         plot_gst(sw, sw->l1map, area, qrv->gst, z_makecol(13, 121, 66));
     }
+
+	if (sw->type == SWT_MAP) {
+		plot_beacons(sw, sw->l1map, band, area);
+	}
+
     if (ctest && ctest->wwlused && sw->type == SWT_MAP) {
         plot_qsos(sw, sw->l1map, band, area);
 		/*if (!fp)*/ plot_gst(sw, sw->l1map, area, sw->gst, z_makecol(250, 180, 52));
@@ -387,6 +412,10 @@ void sw_map_redraw_rect(struct subwin *sw, SDL_Rect *area, struct band *band, in
 		plot_qso(sw, sw->screen, band, &band->tmplocqso);
 		if (gacs) plot_path(sw, sw->screen, band, &band->tmplocqso, &gacs->tmpqso);
 	}
+    if (gacs != NULL) {
+        plot_qso(sw, sw->screen, band, &gacs->infolocqso);
+        plot_path(sw, sw->screen, band, &gacs->infolocqso, &gacs->infoqso);
+    }
 	plot_qth(sw, area);
 }					  
 
@@ -398,7 +427,7 @@ void sw_map_redraw_rotar(struct subwin *sw, SDL_Rect *area, int flags){
     
     SDL_SetClipRect(sw->screen, area);
     memcpy(&r, area, sizeof(r));
-    SDL_BlitSurface(sw->l1map, &r, sw->screen, &r);
+    SDL_BlitSurface(sw->l1map, &r, sw->screen, &r); // comment for reachability snapshot
 	if (sw->type == SWT_MAP){ // no rain for KST A/C info
 	    sw_map_redraw_rain(sw, area, flags);
 	}
@@ -407,16 +436,11 @@ void sw_map_redraw_rotar(struct subwin *sw, SDL_Rect *area, int flags){
 }
 
 void sw_map_update_rotar(struct subwin *sw){
-    SDL_Rect r;
 
 //    dbg("\nsw_map_update_rotar)\n");
-    r.x = 0;
-    r.y = 0;
-    r.w = sw->screen->w;
-    r.h = sw->screen->h;
 
     sw->gdirty=1;
-    sw_map_redraw_rotar(sw, &r, 0);
+	sw_map_redraw(sw, aband, 0);
 } 
 
 void sw_map_redraw_icons(struct subwin *sw, SDL_Rect *area, int flags){
@@ -469,7 +493,7 @@ void sw_map_redraw_rain(struct subwin *sw, SDL_Rect *aarea, int flags){
 
 		km2px_d(sw, scp->kx, scp->ky, &px1, &py1);
 		km2px_d(sw, scp->kx + grain->minscpdist, scp->ky, &px2, &py2);
-		int r = (int)sqrt((px1 - px2)*(px1 - px2) + (py1 - py2)*(py1 - py2));
+		int r = (int)sqrt((double)(px1 - px2)*(px1 - px2) + (py1 - py2)*(py1 - py2));
 		int c = scp->qrb <= grain->maxqrb ? sdl->gr[15] : sdl->gr[5];
 		z_circle(sw->screen, px1, py1, r, c);
 		if (r > 3) z_circle(sw->screen, px1, py1, r - 2, c);
@@ -1174,6 +1198,7 @@ int maps_reload(){
         if (sw->type!=SWT_MAP && sw->type != SWT_KST) continue;
         sw->gdirty=1;
         sw->minqso=NULL;
+		sw->minbeacon=NULL;
 //        zg_free0(sw->minqrvcall);
         map_update_qth(sw);
         map_recalc_gst(sw, aband); // added for band change
@@ -1243,14 +1268,16 @@ void map_recalc_cors(){
 } 
 
 
-struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y){
+struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y, double *min){
     int i;
     struct qso *minq, *q;
-    gdouble d, min;
+	gdouble d;
     int px, py, kx, ky;
     struct subwin *sw;
 
-    if (!b) return NULL;
+	*min = G_MAXDOUBLE;
+	
+	if (!b) return NULL;
     sw=gses->ontop;
     if (sw->type!=SWT_MAP) return NULL;
     
@@ -1259,7 +1286,6 @@ struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y){
     px2km(sw, px, py, &kx, &ky);
     
 
-    min=G_MAXDOUBLE;
     minq=NULL;
     for (i=0; i<b->qsos->len; i++){
         q = (struct qso *)g_ptr_array_index(b->qsos, i);
@@ -1268,8 +1294,8 @@ struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y){
         /*compute_cache(q); */
         d = sqrt((double)(sqr(q->kx-kx)+sqr(q->ky-ky)));
 /*        dbg("  %s %d %d %6.3f\n", q->callsign, q->gfx_x-mouse_x,  q->gfx_y-mouse_y, d);*/
-        if (d<min){
-            min=d;
+        if (d<*min){
+            *min=d;
             minq=q;
         }
     }
@@ -1318,24 +1344,96 @@ gchar *find_nearest_qrv(struct qrvdb *qrvdb, struct band *band, int mouse_x, int
     return minqrv->call;
 }
 
-void plot_nearest_qso(struct subwin *sw, struct band *band){
-    struct qso *oldminqso;
+
+static void find_nearest_beacon_band(struct subwin* sw, struct beaconband* bband, int mouse_x, int mouse_y, gdouble* min, struct beacon** minb) {
+	int kx, ky;
+
+	int px = mouse_x - sw->x * FONT_W;
+	int py = mouse_y - sw->y * FONT_H;
+	px2km(sw, px, py, &kx, &ky);
+    ky--; // distinguish qso and beacon in same locator
+
+	int i;
+	for (i = 0; i < bband->beacons->len; i++) {
+		struct beacon* q = (struct beacon*)g_ptr_array_index(bband->beacons, i);
+		gdouble d = sqrt((double)(sqr(q->kx - kx) + sqr(q->ky - ky)));
+		if (d < *min) {
+			*min = d;
+			*minb = q;
+		}
+	}
+}
+
+struct beacon* find_nearest_beacon(struct band* b, int mouse_x, int mouse_y, gdouble* min) {
+	struct subwin* sw = gses->ontop;
+	if (sw->type != SWT_MAP) return NULL;
+
+	*min = G_MAXDOUBLE;
+	struct beacon* minb = NULL;
+
+	if (!b) {
+		int j;
+		for (j = 0; j < gbeacondb->bands->len; j++) {
+			struct beaconband* bband = (struct beaconband*)g_ptr_array_index(gbeacondb->bands, j);
+			find_nearest_beacon_band(sw, bband, mouse_x, mouse_y, min, &minb);
+		}
+    }else{
+		struct beaconband* bband = get_beacondb_band(gbeacondb, b->bandchar);
+		if (!bband) return NULL;
+
+		find_nearest_beacon_band(sw, bband, mouse_x, mouse_y, min, &minb);
+    }
+	//if (minb) dbg("nearest: %s %s\n", minb->call, minb->wwl);
+	//else dbg("nearest: NULL\n"); 
+	return minb;
+}
+
+void plot_nearest_qso_beacon_ac(struct subwin *sw, struct band *band){
+    struct qso *oldminqso = sw->minqso;
+	struct beacon* oldminbeacon = sw->minbeacon;
+    char oldminacid[AC_ID_MAXLEN];
+    strcpy(oldminacid, sw->minacid);
+	double minq, minb, minac;
 
     if (!sdl) return;
-    oldminqso=sw->minqso;          
-    sw->minqso=find_nearest_qso(band, sdl->mouse_x, sdl->mouse_y);
-    /*dbg("sw->minq=%s  oldminq=%s\n", sw->minq->callsign, oldminq->callsign); */
-    if (sw->minqso==oldminqso) return;
-/*        dbg("minq changed %s->%s\n", oldminq->locator, sw->minq->locator); */
-    SDL_SetClipRect(sw->screen, &sw->map);
-/*       dbg("clip_rect %dx%d%+d%+d\n", surface->clip_rect.x, surface->clip_rect.y, surface->clip_rect.w, surface->clip_rect.h); */
-    if (oldminqso) plot_qso(sw, sw->screen, band, oldminqso);
-    if (sw->minqso) {
-        plot_qso(sw, sw->screen, band, sw->minqso);
-        plot_info_qso(sw, sw->screen, sw->minqso);
-    }else{
-        plot_info_qso(sw, sw->screen, NULL);
+    sw->minqso=find_nearest_qso(band, sdl->mouse_x, sdl->mouse_y, &minq);
+	sw->minbeacon=find_nearest_beacon(band, sdl->mouse_x, sdl->mouse_y, &minb);
+    find_nearest_ac(gacs, sdl->mouse_x, sdl->mouse_y, &minac, &sw->minacid);
+
+    if (sw->minqso != NULL && minq < minb && minq < minac) { sw->minbeacon = NULL; strcpy(sw->minacid, ""); }
+	if (sw->minbeacon != NULL && minb < minq && minb < minac) { sw->minqso = NULL; strcpy(sw->minacid, ""); }
+    if (strlen(sw->minacid) > 0 && minac <= minq && minac <= minb) { sw->minqso = NULL; sw->minbeacon = NULL; }
+
+	if (sw->minqso == oldminqso && sw->minbeacon == oldminbeacon && strcmp(sw->minacid, oldminacid) == 0) return;
+
+	SDL_SetClipRect(sw->screen, &sw->map);
+
+	if (oldminqso) plot_qso(sw, sw->screen, band, oldminqso);
+	if (oldminbeacon) plot_beacon(sw, sw->screen, oldminbeacon);
+    if (strlen(oldminacid) > 0 && gacs != NULL) {
+        MUTEX_LOCK(gacs->sh);
+        struct ac* ac = ac_find_by_id(gacs, oldminacid);
+        plot_ac(sw, ac);
+        MUTEX_UNLOCK(gacs->sh);
     }
+
+	if (sw->minqso) {
+		plot_qso(sw, sw->screen, band, sw->minqso);
+		plot_info_qso(sw, sw->screen, sw->minqso);
+	}else if (sw->minbeacon) {
+		plot_beacon(sw, sw->screen, sw->minbeacon);
+		plot_info_beacon(sw, sw->screen, sw->minbeacon);
+    }else if (strlen(sw->minacid) > 0) {
+        MUTEX_LOCK(gacs->sh);
+        struct ac* ac = ac_find_by_id(gacs, sw->minacid);
+        plot_ac(sw, ac);
+        plot_info_ac(sw, sw->screen, ac);
+        MUTEX_UNLOCK(gacs->sh);
+    }else {
+		plot_info_qso(sw, sw->screen, NULL);
+		plot_info_beacon(sw, sw->screen, NULL);
+        plot_info_ac(sw, sw->screen, NULL);
+	}
 }
     
 /*void plot_nearest_qrv(struct subwin *sw, struct band *band){
@@ -1375,25 +1473,26 @@ void plot_info_qso(struct subwin *sw, SDL_Surface *surface, struct qso *qso){
     rect.h=sw->info.y+(11*FONT_H)+12;
     
     SDL_SetClipRect(surface, &rect);
-    SDL_FillRect(surface, &rect, z_makecol(0,0,135)) ;
+    SDL_FillRect(surface, &rect, z_makecol(0,0,35)) ;
     if (!qso) return;
 
     x=sw->info.x+4;
     y=sw->info.y+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GCALL), q0(qso->callsign)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GWWL),  q0(qso->locator)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQRB),  (int)qso->qrb); y+=FONT_H+4;   
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQTF),  qso->qtf); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GSEN),  q0(qso->rsts), q0(qso->qsonrs)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GRCV),  q0(qso->rstr), q0(qso->qsonrr)); y+=FONT_H+4;
+	int dy = 0;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GCALL), q0(qso->callsign)); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GWWL),  q0(qso->locator)); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQRB),  (int)qso->qrb); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQTF),  qso->qtf); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GSEN),  q0(qso->rsts), q0(qso->qsonrs)); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GRCV),  q0(qso->rstr), q0(qso->qsonrr)); y+=FONT_H+ dy;
     strcpy(s,qso->time_str);
     s[5]=s[4];
     s[4]=s[3];
     s[3]=s[2];
     s[2]=':';
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GTIM),  s); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GOPE),  q0(qso->operator_)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GREM),  q0(qso->remark)); y+=FONT_H+4;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GTIM),  s); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GOPE),  q0(qso->operator_)); y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GREM),  q0(qso->remark)); y+=FONT_H+ dy;
     return;                      
 }
 
@@ -1419,15 +1518,16 @@ void plot_info_qso(struct subwin *sw, SDL_Surface *surface, struct qso *qso){
     if (!qi) return;
 
     color=z_makecol(21, 193, 106);
-
-	zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GCALL), q0(qi->call)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GWWL),  q0(qi->wwl)); y+=FONT_H+4;
-    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GREM),  q0(qi->text)); y+=FONT_H+4;
+    int dy = 0;
+	zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GCALL), q0(qi->call)); y+=FONT_H+dy;
+    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GWWL),  q0(qi->wwl)); y+=FONT_H+dy;
+    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GREM),  q0(qi->text)); y+=FONT_H+dy;
     if (!band) return;
-    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GWKD),  qi->wkd[band->bi]); y+=FONT_H+4;
+    zsdl_printf(surface, x, y, color, 0, ZFONT_TRANSP, VTEXT(T_GWKD),  qi->wkd[band->bi]); y+=FONT_H+dy;
     return;                      
 }*/
 
+
 int plot_qrb_qth(struct subwin *sw, SDL_Surface *surface, int mouse_x, int mouse_y){
     double qrb,qtf, h2, w2; 
     SDL_Rect rect;
@@ -1457,14 +1557,15 @@ int plot_qrb_qth(struct subwin *sw, SDL_Surface *surface, int mouse_x, int mouse
     
     //dbg("plot_qtb_qtf sss='%s'\n", sss);
     zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, sss, (int)(qrb));
-    y+=FONT_H+4;
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQTF), (int)(qtf*180/M_PI)); y+=FONT_H+4;
-   /* fontoutf(surface, x, y, sdl->green, FONT_TRANSP, VTEXT(T_GINC), (int) (gst[(int)(qtf*180/M_PI)%360]/400*100));y+=FONT_H+4; */
+	int dy = 0;
+    y+=FONT_H+ dy;
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQTF), (int)(qtf*180/M_PI)); y+=FONT_H+ dy;
+   /* fontoutf(surface, x, y, sdl->green, FONT_TRANSP, VTEXT(T_GINC), (int) (gst[(int)(qtf*180/M_PI)%360]/400*100));y+=FONT_H+dy; */
 #if -1
 	if (qrbqtf2hw(gses->myh, gses->myw, qrb, qtf, &h2, &w2) == 0){
-        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLON), h2*180.0/M_PI, x2gramin(buf, sizeof(buf), h2*180/M_PI, "EW")); y+=FONT_H+4;
-        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLAT), w2*180.0/M_PI, x2gramin(buf, sizeof(buf), w2*180/M_PI, "NS")); y+=FONT_H+4;
-        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLOC), hw2loc(buf, h2*180/M_PI, w2*180/M_PI, 6)); y+=FONT_H+4;
+        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLON), h2*180.0/M_PI, x2gramin(buf, sizeof(buf), h2*180/M_PI, "EW")); y+=FONT_H+ dy;
+        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLAT), w2*180.0/M_PI, x2gramin(buf, sizeof(buf), w2*180/M_PI, "NS")); y+=FONT_H+ dy;
+        zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLOC), hw2loc(buf, h2*180/M_PI, w2*180/M_PI, 6)); y+=FONT_H+ dy;
     }
 #else    
 	{
@@ -1543,8 +1644,12 @@ void map_for_photo(struct subwin *sw, struct band *band, int flags){
 
     if (minkx == maxkx || minky == maxky) {
         //dbg("minkx=%d maxkx=%d\n", minkx, maxkx);
-        sw->ox = sw->map.w/2; 
-        sw->oy = sw->map.h/2; 
+        km2px(sw, (maxkx + minkx) / 2, (maxky + minky) / 2, &px, &py);
+        dx = sw->map.w / 2 - px;
+        dy = sw->map.h / 2 - py;
+        sw->ox += dx;
+        sw->oy += dy;
+        move_map(sw, band, dx, dy);
         return;  // no qso
     }
  //   dbg("x=%d..%d y=%d..%d  prumer x=%d y=%d\n", minkx, maxkx, minky, maxky, (maxkx+minkx)/2, (maxky+minky)/2);
@@ -1669,12 +1774,42 @@ void map_cor_callback(void)
 		gses->ontop->gdirty = 1;
 		qrv_recalc_wkd(qrv);
 		qrv_recalc_qrbqtf(qrv);
+		beacondb_recalc_qrbqtf(gbeacondb);
 		qrv_recalc_gst(qrv);
 		map_recalc_gst(gses->ontop, aband);
 		sw_map_redraw(gses->ontop, aband, 0);
 	}
 }
 
+
+void sw_map_ac_info_wwl(void* itdata_xxx, void* menudata) {
+    struct subwin* sw = (struct subwin*)menudata;
+
+    if (!gacs) return;
+    if (!sw->wwlunder) return;
+
+    g_free(gacs->infolocqso.locator);
+    gacs->infolocqso.locator = g_strdup(sw->wwlunder);
+
+    //compute_qrbqtf(&gacs->infolocqso);
+    //map_add_qso(&gacs->infolocqso, aband);
+
+    kst_free_screen(sw);
+    sw->l1map = SDL_CreateRGBSurface(SDL_SWSURFACE, sw->w * FONT_W, sw->h * FONT_H, sdl->bpp,
+        sdl->screen->format->Rmask, sdl->screen->format->Gmask, sdl->screen->format->Bmask, 0);
+    sw->screen = SDL_CreateRGBSurface(SDL_SWSURFACE, sw->w * FONT_W, sw->h * FONT_H, sdl->bpp,
+        sdl->screen->format->Rmask, sdl->screen->format->Gmask, sdl->screen->format->Bmask, 0);
+    MUTEX_INIT(sw->screen);
+    sw->gdirty = 1;
+    map_update_layout(sw);
+
+    ac_update_infoctp(gacs->infolocqso.locator);
+    ac_update_tmpctp(gacs->infolocqso.locator);
+
+    sw->zoom = 10000;
+    map_for_photo(sw, aband, MAP_AC_INFO);
+}
+
 #else
 int sw_map_kbd_func(struct subwin *sw, struct event *ev, int fw){
     return 0;
