@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2024 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -30,7 +30,6 @@ void map_clear_qso(struct qso *qso, struct band *band);
 void map_add_qso(struct qso *qso, struct band *band);
 #ifdef Z_HAVE_SDL
 void sw_map_redraw_rect(struct subwin *sw, SDL_Rect *area, struct band *band, int flags);
-void sw_map_compose(struct subwin *sw, SDL_Rect *area);
 void sw_map_redraw_rotar(struct subwin *sw, SDL_Rect *area, int flags);
 void sw_map_redraw_icons(struct subwin *sw, SDL_Rect *area, int flags);
 void sw_map_redraw_rain(struct subwin *sw, SDL_Rect *area, int flags);
@@ -52,10 +51,10 @@ void plot_qrvs(struct subwin *sw, SDL_Surface *surface, struct band *band, SDL_R
 void plot_gst(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, double gst[360], int c);
 void plot_qso(struct subwin *sw, SDL_Surface *surface, struct band *band, struct qso *qso);
 void plot_qsos(struct subwin *sw, SDL_Surface *surface, struct band *band, SDL_Rect *area);
-void plot_nearest_qso(struct subwin *sw, struct band *band);
-void plot_nearest_qrv(struct subwin *sw, struct band *band);
+void plot_nearest_qso_beacon_ac(struct subwin *sw, struct band *band);
+//void plot_nearest_qrv(struct subwin *sw, struct band *band);
 void plot_info_qso(struct subwin *sw, SDL_Surface *surface, struct qso *qso);
-void plot_info_qrv(struct subwin *sw, SDL_Surface *surface, struct band *band, struct qrv_item *qi);
+//void plot_info_qrv(struct subwin *sw, SDL_Surface *surface, struct band *band, struct qrv_item *qi);
 int plot_qrb_qth(struct subwin *sw, SDL_Surface *surface, int mouse_x, int mouse_y);
 void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Rect *outarea);
 
@@ -65,14 +64,14 @@ void zoom(struct subwin *sw, double factor, int centerx, int centery);
 
 int map_update_qth(struct subwin *sw);
 void map_recalc_cors(void);
-struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y);
+struct qso *find_nearest_qso(struct band *b, int mouse_x, int mouse_y, double* min);
 gchar *find_nearest_qrv(struct qrvdb *qrvdb, struct band *band, int mouse_x, int mouse_y);
 void map_for_photo(struct subwin *sw, struct band *band, int flags);
 void map_recalc_gst(struct subwin *sw, struct band *band);
 
 void plot_hgts(struct subwin *sw, SDL_Rect *area);
 void map_cor_callback(void);
-
+void sw_map_ac_info_wwl(void* itdata, void* menudata);
 #endif
 
 
