@@ -11,6 +11,7 @@
 #include "header.h"
 
 #include "adif.h"
+#include "beacondb.h"
 #include "bfu.h"
 #include "charsets.h"
 #include "chart.h"
@@ -312,6 +313,7 @@ static void really_close_ctest(void)
 	maps_reload();
 	maps_update_showwwls();
 	rain_reload();
+	beacondb_recalc_qrbqtf(gbeacondb);
 #endif   
 	chart_reload();
 #ifdef OCT8TOR
@@ -1317,6 +1319,7 @@ static struct menu_item edit_menu[] = {
     {CTEXT(T_EXC_CTEST), "", CTEXT(T_HK_EXC_CTEST),  MENU_FUNC menu_exc_update_contest, NULL, 0, 0},
     {CTEXT(T_EXC_BAND), "", CTEXT(T_HK_EXC_BAND),  MENU_FUNC menu_exc_update_band, NULL, 0, 0},
     {CTEXT(T_IMPORT_MMM), "", CTEXT(T_HK_IMPORT_MMM),  MENU_FUNC menu_import_mmm, NULL, 0, 0},
+    {CTEXT(T_IMPORT_BEACONS), "", CTEXT(T_HK_IMPORT_BEACONS),  MENU_FUNC menu_import_beaconspot, NULL, 0, 0},
     {NULL, NULL, NULL, NULL, NULL, 0, 0}
 };
 
@@ -1335,6 +1338,7 @@ static struct menu_item edit_menu2[] = {
 #endif
     {"", "", M_BAR, NULL, NULL, 0, 0},
     {CTEXT(T_IMPORT_MMM), "", CTEXT(T_HK_IMPORT_MMM),  MENU_FUNC menu_import_mmm, NULL, 0, 0},
+    {CTEXT(T_IMPORT_BEACONS), "", CTEXT(T_HK_IMPORT_BEACONS),  MENU_FUNC menu_import_beaconspot, NULL, 0, 0},
     {NULL, NULL, NULL, NULL, NULL, 0, 0}
 };
 
