@@ -10,6 +10,7 @@
 
 #include "header.h"
 
+#include "beacondb.h"
 #include "bfu.h"
 #include "chart.h"
 #include "edi.h"
@@ -1155,6 +1156,7 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
             maps_reload();
 			maps_update_showwwls();
 			rain_reload();
+			beacondb_recalc_qrbqtf(gbeacondb);
 #endif   
             chart_reload();
 			//qrv_recalc_wkd(qrvdb); probably not needed
