@@ -11,6 +11,7 @@
 
 #include "header.h"
 
+#include "beacondb.h"
 #include "bfu.h"
 #include "control.h"
 #include "cwdb.h"
@@ -432,6 +433,7 @@ void menu_recalc_qrb(void *arg){
     qrv_recalc_wkd(qrv);
     qrv_recalc_qrbqtf(qrv);
     qrv_recalc_gst(qrv);
+	beacondb_recalc_qrbqtf(gbeacondb);
 }
 
 /******************** UPDATE C_W ******************************/
