@@ -37,7 +37,7 @@ struct menu_item no_cq_defined_menu[] = {
  
 char cw_str[MAX_STR_LEN], cw_speed_str[EQSO_LEN];
 int cw_repeat, cw_breakable;
-char cw_ts_str[EQSO_LEN];
+char cw_sec_str[EQSO_LEN];
 int cw_allowifundef;    
 
 
@@ -50,7 +50,7 @@ void refresh_cq_cw(void *xxx){
     cq->cw_speed = atoi(cw_speed_str);
 	cq->cw_repeat = cw_repeat;
 	cq->cw_breakable = cw_breakable;
-    cq->cw_ts  = atoi(cw_ts_str);
+    cq->cw_ts  = 10*atof(cw_sec_str);
     cq->cw_allowifundef = cw_allowifundef;
 
 #ifdef AUTOSAVE
@@ -146,7 +146,7 @@ void cq_cw(void *arg){
     g_snprintf(cw_speed_str, EQSO_LEN, "%d", cq->cw_speed);
 	cw_repeat = cq->cw_repeat;
 	cw_breakable = cq->cw_breakable;
-    g_snprintf(cw_ts_str, EQSO_LEN, "%d", cq->cw_ts);
+    g_snprintf(cw_sec_str, EQSO_LEN, "%3.1f", cq->cw_ts / 10.0);
     cw_allowifundef = cq->cw_allowifundef;
 
     
@@ -183,10 +183,10 @@ void cq_cw(void *arg){
 
 	d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
-    d->items[i].data = cw_ts_str;
-    d->items[i].fn   = check_number;
+    d->items[i].data = cw_sec_str;
+    d->items[i].fn   = check_double;
     d->items[i].gid  = 0;
-    d->items[i].gnum = 300;
+    d->items[i].gnum = 120;
     
     d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 0;
@@ -242,7 +242,7 @@ void menu_cq_cw(void *arg){
 
 char ssb_file[MAX_STR_LEN];
 int ssb_repeat, ssb_breakable;
-char ssb_ts_str[EQSO_LEN];
+char ssb_sec_str[EQSO_LEN];
 
 void refresh_cq_ssb(void *xxx){
     struct cq *cq;
@@ -252,7 +252,7 @@ void refresh_cq_ssb(void *xxx){
     STORE_STR(cq, ssb_file);
 	cq->ssb_repeat = ssb_repeat;
 	cq->ssb_breakable = ssb_breakable;
-    cq->ssb_ts  = atoi(ssb_ts_str);
+    cq->ssb_ts  = 10 * atof(ssb_sec_str);
 
 #ifdef AUTOSAVE
     menu_save_rc(NULL);
@@ -336,7 +336,7 @@ void cq_ssb(void *arg){
     safe_strncpy0(ssb_file, cq->ssb_file, MAX_STR_LEN);
 	ssb_repeat = cq->ssb_repeat;
 	ssb_breakable = cq->ssb_breakable;
-    g_snprintf(ssb_ts_str, EQSO_LEN, "%d", cq->ssb_ts);
+    g_snprintf(ssb_sec_str, EQSO_LEN, "%3.1f", cq->ssb_ts / 10.0);
 
     
     if (!(d = g_malloc(sizeof(struct dialog) + 55 * sizeof(struct dialog_item)))) return;
@@ -365,10 +365,10 @@ void cq_ssb(void *arg){
 
 	d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
-    d->items[i].data = ssb_ts_str;
-    d->items[i].fn   = check_number;
+    d->items[i].data = ssb_sec_str;
+    d->items[i].fn   = check_double;
     d->items[i].gid  = 0;
-    d->items[i].gnum = 300;
+    d->items[i].gnum = 120;
     
     d->items[++i].type = D_BUTTON; 
     d->items[i].gid = B_ENTER;
