@@ -344,8 +344,11 @@ void menu_set_mode(void *itdata, void *menudata)
 	add_to_menu(&mi, CTEXT(T_FM), "F", "F", MENU_FUNC choose_mode, GINT_TO_POINTER(MOD_FM_FM), 0);
 	if (gses->mode == MOD_FM_FM) sel = 3;
 
-	add_to_menu(&mi, CTEXT(T_RTTY), "R", "R", MENU_FUNC choose_mode, GINT_TO_POINTER(MOD_RTTY_RTTY), 0);
-	if (gses->mode == MOD_RTTY_RTTY) sel = 4;
+	add_to_menu(&mi, CTEXT(T_MGM), "M", "M", MENU_FUNC choose_mode, GINT_TO_POINTER(MOD_MGM_MGM), 0);
+	if (gses->mode == MOD_MGM_MGM) sel = 4;
+
+    add_to_menu(&mi, CTEXT(T_ATV), "T", "T", MENU_FUNC choose_mode, GINT_TO_POINTER(MOD_ATV_ATV), 0);
+    if (gses->mode == MOD_ATV_ATV) sel = 5;
 
     set_window_ptr(gses->win, (term->x - 6 - 6) / 2, (term->y - 2 - 5) / 2);
 
