@@ -20,6 +20,7 @@
 
 #include <Windows.h>
 #include <Dbghelp.h>
+#include <crtdbg.h>
 
 int CALLBACK WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow){
 	WSADATA wsaData;
@@ -32,6 +33,7 @@ int CALLBACK WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLi
 	const char *hlver;
 #endif
 
+	_CrtSetDbgFlag(_CRTDBG_CHECK_ALWAYS_DF);
 	//rig_load_all_backends();
 	//RIG *tmprig = rig_init(228);
 
