@@ -947,7 +947,7 @@ int init_sound(){
     dup2(fds[0], 0);
     closesocket(fds[0]);
     for (i=3;i<1024;i++) close(i);
-    execlp("soundwrapper", "soundwrapper", NULL);
+    execlp("soundwrapper", "soundwrappes", "-q", NULL);
 	exit(-1);
 #else
 	return 0;
