@@ -29,7 +29,7 @@ int pa_read2(struct dsp *dsp, void *data, int len);
 int pa_reset2(struct dsp *dsp);
 int pa_sync2(struct dsp *dsp);
 int pa_set_sdr_format(struct dsp *dsp, int frames, int speed, int rec);
-int pa_find_device(const char* name, int play, int rec);
+int pa_find_device(const char* name, PaHostApiIndex hostapi, int play, int rec);
 
 #endif
 
