@@ -113,6 +113,9 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 #endif
 				{
 					safe_strncpy(rot->rot->state.rotport.pathname, crot->rot_filename, HAMLIB_FILPATHLEN - 1);
+                    /* from 4.5
+                    hamlib_port_t* rotp = ROTPORT(*rot->rot);
+                    strncpy(rotp->pathname, crot->rot_filename, HAMLIB_FILPATHLEN - 1);*/
 				}
 				if (rot->rot_speed > 0) rot->rot->state.rotport.parm.serial.rate = rot->rot_speed;
 
