@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2021 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -13,6 +13,8 @@
 
 #include "header.h"
 
+#include "oct8tor.h"
+
 struct sdev;
 
 #ifdef __GNUC__
@@ -24,12 +26,12 @@ struct sdev;
 	g_string_free(gs, TRUE); \
 }
 #else
-#define TRROT(thr, m, ...) if (cfg->trace_sdev >= (thr ? 2 : 1)){ \
-    GString *gs = g_string_new("ROT: "); \
-    if (thr) g_string_append(gs, "           "); \
-	g_string_append_printf(gs, m, __VA_ARGS__); \
-	trace(1, "%s", gs->str); \
-	g_string_free(gs, TRUE); \
+#define TRROT(thr, ...) if (cfg->trace_sdev >= (thr ? 2 : 1)){ \
+    GString *gsxy = g_string_new("ROT: "); \
+    if (thr) g_string_append(gsxy, "           "); \
+	g_string_append_printf(gsxy, __VA_ARGS__); \
+	trace(1, "%s", gsxy->str); \
+	g_string_free(gsxy, TRUE); \
 }
 #endif
 
@@ -38,7 +40,10 @@ enum rot_type {
     ROT_OK1ZIA_TTYS=1,
     ROT_OK1ZIA_FTDI=2,
     ROT_HAMLIB=3,
-    ROT_REMOTE=4
+    ROT_REMOTE=4,
+#ifdef OCT8TOR
+	ROT_OCT8TOR = 5
+#endif
 };
 
 struct config_rotar{
@@ -72,6 +77,9 @@ struct rotar{
     struct sdev *sdev;
 #ifdef HAVE_HAMLIB
     ROT *rot;
+#endif
+#ifdef OCT8TOR
+	struct oct8tor *oct;
 #endif
     int step;      
     int rotchar; /* A, B, ... */
@@ -97,7 +105,7 @@ struct rotar{
     int last_req;
 #ifdef HAVE_HAMLIB
     GThread *hl_thread;
-    int hl_azim, hl_elev;
+    int hl_azim, hl_elev, hl_stop;
     int hl_model;
     int hl_give_me_chance;
     int hl_thread_break;
@@ -105,12 +113,20 @@ struct rotar{
 	elevation_t hl_lastelev;
 #endif
 	int poll_ms;
+#ifdef OCT8TOR
+	int oct_nr;
+	int oct_azim, oct_elev, oct_stop;
+	bool oct_hidden;
+	char oct_sys;
+#endif
+    GThread *main_thread;
 };
 
 
 extern GPtrArray *rotars;
 extern MUTEX_DEFINE(rotars);
 extern struct rotar *rotar;
+extern struct oct8tor *goct8tor;
 
 
 int init_rotars(void);
@@ -119,6 +135,8 @@ int free_rotars(void);
 struct rotar *init_rotar(struct config_rotar *cfg, int rotchar);
 void free_rotar(struct rotar *rot);
 int rot_seek(struct rotar *rot, int uhel, int elev /* -90 unused */);
+void rotars_stop(void);
+void rotar_stop(struct rotar *rot);
 struct config_rig *get_config_rig_by_number(GPtrArray *crigs, int nr);
 struct config_rotar *get_config_rotar_by_number(GPtrArray *rotars, int nr);
 struct rotar *get_rotar(int nr);
@@ -138,4 +156,8 @@ gpointer rot_hamlib_main(gpointer xxx);
 
 int rot_normalize(int az);
 
+char rot_get_rotchar_by_oct_nr(int oct_nr);
+char rot_get_rotchar_by_ch(const char *ch);
+char rot_get_rotchar_by_sys(const char *sys);
+
 #endif
