@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@ struct ssbd *init_ssbd(){
     return ssbd;
 }
 
-void free_ssbd(struct ssbd *ssbd){
+void free_ssbd(struct ssbd *ssbd, int terminate){
 	progress(VTEXT(T_FREE_SSB_CQ));		
     cq_abort(1);
     ssbd_abort(ssbd,1); 
@@ -107,6 +107,9 @@ void free_ssbd(struct ssbd *ssbd){
     MUTEX_FREE(ssbd->loglevel);
     MUTEX_FREE(ssbd->seek);
 #endif // HAVE_SNDFILE
+#ifdef HAVE_PORTAUDIO
+    if (terminate) Pa_Terminate();
+#endif
     g_free(ssbd);
 }
 
