@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2016 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2024 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,6 +16,7 @@
 #include "ac.h"
 
 struct band;
+struct beacon;
 
 #define BANDMAPW 22
 #define BANDMAPMINW (75+BANDMAPW)
@@ -79,8 +80,10 @@ struct subwin {
     int gdirty;
     SDL_Rect map, info;
     gchar *pwwlo;
-    struct qso *minqso;
-    //gchar *minqrvcall;
+	struct qso* minqso;
+	struct beacon *minbeacon;
+    char minacid[AC_ID_MAXLEN];
+	//gchar *minqrvcall;
     int scope_mode;
     int fft_wf_y, fft_wf_h;  
     int fft_sp_y, fft_sp_h;
@@ -120,6 +123,7 @@ struct subwin {
 	char *callunder;
 	char *refunder;
 	char *acunder;
+    char *wwlunder;
 	int uhel;
 	GPtrArray* callsunder;
 	int callunderx, callundery;
