@@ -644,9 +644,9 @@ gpointer trig_main(gpointer xxx){
         job = trig_job_get(trig);
         if (!job){
             usleep(trig->poll_ms * 1000);
-			ST_START();
+			//ST_START();
 			rigerr = rig_get_vfo(trig->rig, &vfo);
-			ST_STOP("rig_get_vfo");
+			//ST_STOP("rig_get_vfo");
 			if (rigerr == -RIG_ENAVAIL){
                 vfo = RIG_VFO_CURR;
             }else{
@@ -657,12 +657,12 @@ gpointer trig_main(gpointer xxx){
                 }
             }
 
-			ST_START();
+			//ST_START();
             usleep(trig->poll_ms * 1000);
-			ST_STOP("poll_ms");
-			ST_START();
+			//ST_STOP("poll_ms");
+			//ST_START();
 			rigerr = rig_get_freq(trig->rig, vfo, &freq);
-			ST_STOP("rig_get_freq");
+			//ST_STOP("rig_get_freq");
             if (rigerr != RIG_OK){
 				TRTR(1, "rig_get_freq(#%d, %s)", trig->nr, rig_strvfo(vfo));
                 gtrigs->rigerr = trig->rigerr = rigerr;
