@@ -482,8 +482,8 @@ int sdl_setvideomode(int w, int h, int init_x){
 		return 1;    
 	}
 	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse, NULL);
-
 #endif
+
 #ifdef Z_HAVE_SDL2
 	dbg("SDL_CreateWindow(%d,%d)\n", w, h);
 
@@ -533,6 +533,13 @@ int sdl_setvideomode(int w, int h, int init_x){
 	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse, NULL);
 #endif
 
+#ifdef Z_HAVE_SDL1
+    zsdl->pxformat = g_new0(SDL_PixelFormat, 1);
+    memcpy(zsdl->pxformat, sdl->screen->format, sizeof(SDL_PixelFormat));
+    dbg("tsdl_init  RMask=%x  GMask=%x  BMask=%x  AMask=%x\n", zsdl->pxformat->Rmask, zsdl->pxformat->Gmask, zsdl->pxformat->Bmask, zsdl->pxformat->Amask);
+
+#endif
+
 #ifdef Z_HAVE_SDL2
     zsdl->window = win;
     zsdl->format = format;
@@ -1092,7 +1099,9 @@ gpointer sdl_event_thread(gpointer handle){
 			strcpy(type, "KEYDOWN");
 			//if (sev.key.keysym.sym != SDLK_LCTRL && sev.key.keysym.sym != SDLK_RCTRL && sev.key.keysym.sym != SDLK_LALT && sev.key.keysym.sym != SDLK_RALT && sev.key.keysym.sym != SDLK_LSHIFT && sev.key.keysym.sym != SDLK_RSHIFT)
             if (cfg->trace_keys) {
+#ifdef Z_HAVE_SDL2
                 if (sev.key.keysym.scancode != SDL_SCANCODE_LCTRL)
+#endif                    
                     dbg("KEYDOWN: scan=%d sym=%d '%c' mod=%d (%s)   GetMods=(%s)\n", sev.key.keysym.scancode, sev.key.keysym.sym, sev.key.keysym.sym, sev.key.keysym.mod, dumpmods(&sev.key.keysym), dumpmods(NULL));
             }
 
@@ -1433,12 +1442,14 @@ gpointer sdl_event_thread(gpointer handle){
                 ev.x='q';
                 ev.y=KBD_ALT;
                 goto send;
+#ifdef Z_HAVE_SDL2
             case SDL_APP_WILLENTERBACKGROUND:
                 sdl->paused = 1;
                 break;
             case SDL_APP_DIDENTERFOREGROUND:
                 sdl->paused = 0;
                 break;
+#endif                
         }
         continue;
 sendkeydown:        
@@ -1751,8 +1762,8 @@ void tsdl_change_font(char how){
 
 	if (how == '+'){
 #ifdef Z_HAVE_SDL_TTF
-        if (zsdl->ttf != NULL) {
-            if (cfg->fontheight >= 40) return;
+        if (1) {
+            if (cfg->fontheight >= 64) return;
             cfg->fontheight += 2;
         }
         else
@@ -1766,7 +1777,7 @@ void tsdl_change_font(char how){
 	}
 	if (how == '-'){
 #ifdef Z_HAVE_SDL_TTF
-        if (zsdl->ttf != NULL) {
+        if (1) {
             if (cfg->fontheight <= 12) return;
             cfg->fontheight -= 2;
         }
