@@ -23,7 +23,7 @@ struct wizz_qsomult_item{
 struct wizz_item{
     gchar *tname, *pexch;
     enum tttype tttype;
-    int qsoused, qsomult, qsoglob;
+    int qsoused, qsomult, qsoglob, expmode;
     int wwlused, wwlbonu, wwlmult, wwlcfm; 
     int excused, excbonu, excmult, exccfm;
     enum exctype exctype;
