@@ -228,7 +228,7 @@ void zosk_draw_key_text(struct zosk *zosk, struct zosk_key *key){
 	
 	if (zosk->fn->pressed && key->symFn != SDLK_UNKNOWN) c = key->textFn; 
 	if (zosk->shift->pressed && key->symShift != SDLK_UNKNOWN) c = key->textShift; 
-	fh = zsdl_max_font_h(key->w - 2, key->h - 2, c);
+	fh = zsdl_max_font_h(key->w - 6, key->h - 6, c);
 	color = z_makecol(255, 255, 255);
 
 	switch ((int)key->sym){
@@ -536,26 +536,32 @@ int zosk_send(struct zosk *zosk){
 	SDL_PushEvent(&ev);
     //dbg("push %d\n", ev.key.keysym.sym);
 
-	if (!zosk->ctrl->pressed && !zosk->alt->pressed && ev.type == SDL_TEXTINPUT){
-        g_string_append(zosk->gs, ev.text.text);
+	if (!zosk->ctrl->pressed && !zosk->alt->pressed)
+    {
+#ifdef Z_HAVE_SDL2        
+		if (ev.type == SDL_TEXTINPUT){
+			g_string_append(zosk->gs, ev.text.text);
+		}
+
+        if (ev.type == SDL_KEYDOWN)
+#endif            
+        {
+            if (ev.key.keysym.sym >= ' ' && ev.key.keysym.sym < 128){
+                if (zosk->shift->pressed || (zosk->flags & ZOSK_UPCONVERT))
+                    g_string_append_c(zosk->gs, z_char_uc((char)ev.key.keysym.sym));
+                else
+                    g_string_append_c(zosk->gs, (char)ev.key.keysym.sym);
+
+            }
+            if (ev.key.keysym.sym == SDLK_BACKSPACE && zosk->gs->len > 0){
+                g_string_erase(zosk->gs, zosk->gs->len - 1, 1);
+            }
+            if (ev.key.keysym.sym == SDLK_RETURN && (zosk->flags & ZOSK_CLEARENTER)){
+                g_string_truncate(zosk->gs, 0);
+            }
+        }
     }
 
-	if (!zosk->ctrl->pressed && !zosk->alt->pressed && ev.type == SDL_KEYDOWN){
-		if (ev.key.keysym.sym >= ' ' && ev.key.keysym.sym < 128){
-			if (zosk->shift->pressed || (zosk->flags & ZOSK_UPCONVERT))
-				g_string_append_c(zosk->gs, z_char_uc((char)ev.key.keysym.sym));
-			else
-				g_string_append_c(zosk->gs, (char)ev.key.keysym.sym);
-
-		}
-		if (ev.key.keysym.sym == SDLK_BACKSPACE && zosk->gs->len > 0){
-			g_string_erase(zosk->gs, zosk->gs->len - 1, 1);
-		}
-		if (ev.key.keysym.sym == SDLK_RETURN && (zosk->flags & ZOSK_CLEARENTER)){
-			g_string_truncate(zosk->gs, 0);
-		}
-	}
-
 	if (!key->isshift){
 		for (i = 0; i < zosk->keys->len; i++){
 			struct zosk_key *key2 = (struct zosk_key *)g_ptr_array_index(zosk->keys, i);  
